From f8fc1ba51b1a5a874ed5b7ccff0a99a46faf59fa Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?J=C3=B6rn-Ingo=20Weiegert?= <jiweigert@gmail.com>
Date: Mon, 24 Dec 2012 07:51:13 +0100
Subject: [PATCH 4/5] cfgroot: modifing age-function and Response-header

---
 config/cfgroot/general-functions.pl |   61 ++++++++++++++++++++++++++++++++++-
 config/cfgroot/header.pl            |    2 +-
 2 files changed, 61 insertions(+), 2 deletions(-)

diff --git a/config/cfgroot/general-functions.pl b/config/cfgroot/general-functions.pl
index c14f990..ce080b4 100644
--- a/config/cfgroot/general-functions.pl
+++ b/config/cfgroot/general-functions.pl
@@ -140,10 +140,25 @@ sub writehashpart
 }
 
 sub age
+#### 
+# Modified: 2012-12-21 - nightshift
+# Desc: 
+# Returns Time in (translated) single and plural terms now.
+# Dont print time part if there is no need to do it.
+# Examples: 
+# - System runs for 45 Seconds, it will just print the seconds part.
+# - System runs for more than 3 hours, it will print out hours, minutes, seconds 
+#   but not the days, which make no sense at all. I hope you get it. ;)
+####
+
 {
 	my ($dev, $ino, $mode, $nlink, $uid, $gid, $rdev, $size,
 	        $atime, $mtime, $ctime, $blksize, $blocks) = stat $_[0];
 	my $now = time;
+	my $timestring = '';
+	my $dset = 0;		# Day is set, when > 0
+	my $hset = 0;		# Hour is set, when > 0
+	my $mset = 0;		# Minute is set, when > 0
 
 	my $totalsecs = $now - $mtime;
 	my $days = int($totalsecs / 86400);
@@ -153,9 +168,53 @@ sub age
 	my $mins = $totalmins % 60;
 	my $secs = $totalsecs % 60;
 
-	return "${days}d ${hours}h ${mins}m ${secs}s";
+	if	($days > 1) { 
+		${timestring} .= ${days}.' '.$Lang::tr{'days'}.', ';
+		$dset = 1; 
+	}
+	elsif	($days == 1) { 
+		${timestring} .= ${days}.' '.$Lang::tr{'day'}.', ';
+		$dset = 1; 
+	}
+
+	if	(($hours > 1) && !($dset)) { 
+		${timestring} .= ${hours}.' '.$Lang::tr{'hours'}.', ';
+		$hset = 1;
+	}
+	elsif	(($hours == 1) && !($dset)) { 
+		${timestring} .= ${hours}.' '.$Lang::tr{'hour'}.', ';
+		$hset = 1;
+	}
+	elsif ($dset) {
+		${timestring} .= ${hours}.' '.$Lang::tr{'shour'}.', ';
+		$hset = 1;
+	}
+
+	if	((($mins > 1) || ($mins == 0)) && !($dset || $hset)) { 
+		${timestring} .= ${mins}.' '.$Lang::tr{'minutes'}.', ';
+		$mset = 1;
+	}
+	elsif	(($mins == 1) && !($dset || $hset)) { 
+		${timestring} .= ${mins}.' '.$Lang::tr{'minute'}.', ';
+		$mset = 1;
+	}
+	else {
+		${timestring} .= ${mins}.' '.$Lang::tr{'sminute'}.', '; 
+		$mset = 1;
+	}
+
+	if	((($secs > 1) || ($secs == 0)) && !($dset || $hset || $mset)) { 
+		${timestring} .= ${secs}.' '.$Lang::tr{'seconds'};
+	}
+	elsif	(($secs == 1) && !($dset || $hset || $mset)) { 
+		${timestring} .= $secs.' '.$Lang::tr{'second'};
+	}
+	else	{ ${timestring} .= $secs.' '.$Lang::tr{'ssecond'}; }
+
+	return ${timestring};
 }
 
+
 sub validip
 {
 	my $ip = $_[0];
diff --git a/config/cfgroot/header.pl b/config/cfgroot/header.pl
index bbb0eca..cc721e6 100644
--- a/config/cfgroot/header.pl
+++ b/config/cfgroot/header.pl
@@ -164,7 +164,7 @@ sub showhttpheaders
 	print "Pragma: no-cache\n";
 	print "Cache-control: no-cache\n";
 	print "Connection: close\n";
-	print "Content-type: text/html\n\n";
+	print "Content-Type: text/html; charset=UTF-8\n\n";
 }
 
 sub is_menu_visible($) {
-- 
1.7.9.5

